@@ -110,7 +110,13 @@ cols_move <- function(
 ) {
 
   # Perform input object validation
-  stop_if_not_gt_tbl(data = data)
+  stop_if_not_gt_tbl_or_group(data = data)
+
+  # Handle gt_group
+  if(inherits(data, "gt_group")){
+    arg_list <- as.list(match.call())
+    return(apply_to_grp(data, arg_list))
+  }
 
   # if no `columns` are provided, return data unaltered
   if (rlang::quo_is_missing(rlang::enquo(columns))) {
@@ -261,7 +267,13 @@ cols_move_to_start <- function(
 ) {
 
   # Perform input object validation
-  stop_if_not_gt_tbl(data = data)
+  stop_if_not_gt_tbl_or_group(data = data)
+
+  # Handle gt_group
+  if(inherits(data, "gt_group")){
+    arg_list <- as.list(match.call())
+    return(apply_to_grp(data, arg_list))
+  }
 
   # if no `columns` are provided, return data unaltered
   if (rlang::quo_is_missing(rlang::enquo(columns))) {
@@ -387,7 +399,13 @@ cols_move_to_end <- function(
 ) {
 
   # Perform input object validation
-  stop_if_not_gt_tbl(data = data)
+  stop_if_not_gt_tbl_or_group(data = data)
+
+  # Handle gt_group
+  if(inherits(data, "gt_group")){
+    arg_list <- as.list(match.call())
+    return(apply_to_grp(data, arg_list))
+  }
 
   # if no `columns` are provided, return data unaltered
   if (rlang::quo_is_missing(rlang::enquo(columns))) {
