@@ -14,7 +14,7 @@
 #
 #  This file is part of the 'rstudio/gt' project.
 #
-#  Copyright (c) 2018-2024 gt authors
+#  Copyright (c) 2018-2025 gt authors
 #
 #  For full copyright and license information, please look at
 #  https://gt.rstudio.com/LICENSE.html
@@ -36,10 +36,10 @@ dt_row_groups_init <- function(data) {
 
   stub_df <- dt_stub_df_get(data = data)
 
-  if (any(!is.na(stub_df[["group_id"]]))) {
-    row_groups <- unique(stub_df[["group_id"]])
+  if (all(is.na(stub_df[["group_id"]]))) {
+    row_groups <- character(0L)
   } else {
-    row_groups <- character(0)
+    row_groups <- unique(stub_df[["group_id"]])
   }
 
   dt_row_groups_set(data = data, row_groups = row_groups)
