@@ -200,6 +200,17 @@
 #'   This option is disregarded when using accounting notation with
 #'   `accounting = TRUE`.
 #'
+#' @param min_sep_threshold *Minimum digit threshold for grouping separators*
+#'
+#'   `scalar<numeric|integer>(val>=1)` // *default:* `1`
+#'
+#'   The minimum number of digits required in the integer part of a number for
+#'   grouping separators to be applied. This parameter determines when digit
+#'   grouping begins based on the magnitude of values. The value `1` (the
+#'   default) applies separators starting at 4-digit numbers (e.g., `1,000` and
+#'   above). A value of `2` starts grouping at 5-digit numbers (`10,000` and
+#'   above), while `3` begins at 6-digit numbers (`100,000` and above).
+#'
 #' @param system *Numbering system for grouping separators*
 #'
 #'   `singl-kw:[intl|ind]` // *default:* `"intl"`
@@ -231,7 +242,6 @@
 #' formatting. This is to say that cells of incompatible data types may be
 #' targeted, but there will be no attempt to format them.
 #'
-#'
 #' @section Compatibility of arguments with the `from_column()` helper function:
 #'
 #' [from_column()] can be used with certain arguments of `fmt_number()` to
@@ -251,6 +261,7 @@
 #' - `sep_mark`
 #' - `dec_mark`
 #' - `force_sign`
+#' - `min_sep_threshold`
 #' - `system`
 #' - `locale`
 #'
@@ -416,6 +427,7 @@ fmt_number <- function(
     sep_mark = ",",
     dec_mark = ".",
     force_sign = FALSE,
+    min_sep_threshold = 1,
     system = c("intl", "ind"),
     locale = NULL
 ) {
@@ -441,6 +453,7 @@ fmt_number <- function(
   # - sep_mark
   # - dec_mark
   # - force_sign
+  # - min_sep_threshold
   # - system
   # - locale
 
@@ -496,6 +509,7 @@ fmt_number <- function(
           sep_mark = p_i$sep_mark %||% sep_mark,
           dec_mark = p_i$dec_mark %||% dec_mark,
           force_sign = p_i$force_sign %||% force_sign,
+          min_sep_threshold = p_i$min_sep_threshold %||% min_sep_threshold,
           system = p_i$system %||% system,
           locale = p_i$locale %||% locale
         )
@@ -520,6 +534,7 @@ fmt_number <- function(
   # Use locale-based marks if a locale ID is provided
   sep_mark <- get_locale_sep_mark(locale, sep_mark, use_seps)
   dec_mark <- get_locale_dec_mark(locale, dec_mark)
+  min_sep_threshold <- get_locale_min_sep_threshold(locale, min_sep_threshold)
 
   # Normalize the `suffixing` input to either return a character vector
   # of suffix labels, or NULL (the case where `suffixing` is FALSE)
@@ -586,6 +601,7 @@ fmt_number <- function(
             drop_trailing_zeros = drop_trailing_zeros,
             drop_trailing_dec_mark = drop_trailing_dec_mark,
             format = formatC_format,
+            min_sep_threshold = min_sep_threshold,
             system = system
           )
 
@@ -688,6 +704,7 @@ fmt_number <- function(
 #' - `pattern`
 #' - `sep_mark`
 #' - `force_sign`
+#' - `min_sep_threshold`
 #' - `system`
 #' - `locale`
 #'
@@ -804,6 +821,7 @@ fmt_integer <- function(
     pattern = "{x}",
     sep_mark = ",",
     force_sign = FALSE,
+    min_sep_threshold = 1,
     system = c("intl", "ind"),
     locale = NULL
 ) {
@@ -824,6 +842,7 @@ fmt_integer <- function(
   # - pattern
   # - sep_mark
   # - force_sign
+  # - min_sep_threshold
   # - system
   # - locale
 
@@ -867,6 +886,7 @@ fmt_integer <- function(
           pattern = p_i$pattern %||% pattern,
           sep_mark = p_i$sep_mark %||% sep_mark,
           force_sign = p_i$force_sign %||% force_sign,
+          min_sep_threshold = p_i$min_sep_threshold %||% min_sep_threshold,
           system = p_i$system %||% system,
           locale = p_i$locale %||% locale
         )
@@ -895,6 +915,7 @@ fmt_integer <- function(
     sep_mark = sep_mark,
     dec_mark = "not used",
     force_sign = force_sign,
+    min_sep_threshold = min_sep_threshold,
     system = system,
     locale = locale
   )
