@@ -60,11 +60,8 @@ render_as_html <- function(data) {
   # Create the body component
   body_component <- create_body_component_h(data = data)
 
-  # Create the source notes component
-  source_notes_component <- create_source_notes_component_h(data = data)
-
-  # Create the footnotes component
-  footnotes_component <- create_footnotes_component_h(data = data)
+  # Create the combined footer component (source notes and footnotes)
+  footer_component <- create_footer_component_h(data = data)
 
   # Get attributes for the gt table
   table_defs <- get_table_defs(data = data)
@@ -90,8 +87,7 @@ render_as_html <- function(data) {
     table_defs$table_colgroups,
     table_head,
     body_component,
-    source_notes_component,
-    footnotes_component
+    footer_component
   )
 }
 
