@@ -14,7 +14,7 @@
 #
 #  This file is part of the 'rstudio/gt' project.
 #
-#  Copyright (c) 2018-2024 gt authors
+#  Copyright (c) 2018-2025 gt authors
 #
 #  For full copyright and license information, please look at
 #  https://gt.rstudio.com/LICENSE.html
@@ -443,12 +443,7 @@ summary_rows <- function(
     data$`_data` <-
       dplyr::mutate(
         data$`_data`,
-        !!rowname_col_private := rep("", nrow(data$`_data`))
-      )
-    data$`_data` <-
-      dplyr::relocate(
-        data$`_data`,
-        dplyr::all_of(rowname_col_private),
+        !!rowname_col_private := rep("", nrow(data$`_data`)),
         .after = dplyr::last_col()
       )
 
