@@ -329,6 +329,14 @@
 #'   (when `footnotes.multiline == FALSE`). The default value is a single space
 #'   character (`" "`).
 #'
+#' @param footnotes.order
+#'   *Order footnotes are displayed in output*
+#'
+#'   The order in which footnotes are displayed in the output. By default
+#'   `"marks_last"` with marked footnotes below unmarked ones, or alternatively
+#'   `"marks_first"`. To preserve the order supplied by tab_footnote,
+#'   `"preserve_order"` can be used.
+#'
 #' @param source_notes.border.bottom.style,source_notes.border.bottom.width,source_notes.border.bottom.color
 #'   *Properties of the bottom border belonging to the source notes*
 #'
@@ -564,6 +572,15 @@
 #'   floating position within the code chunk argument `tbl-pos`. The output
 #'   table will only float if `latex.use_longtable = FALSE`.
 #'
+#' @param latex.unicode_conversion
+#'
+#'   *Specify where possible convert unicode to latex*
+#'
+#'   Not all latex converters can handle unicode. or there may be a unicode
+#'   value in the text that cannot be handled by the latex engine. In this case
+#'   turn on this option by setting `latex.unicode_conversion = TRUE` and it
+#'   will replace all unicode it can with equivalent latex calls.
+#'
 #' @return An object of class `gt_tbl`.
 #'
 #' @section Examples:
@@ -832,6 +849,7 @@ tab_options <- function(
     footnotes.spec_ftr = NULL,
     footnotes.multiline = NULL,
     footnotes.sep = NULL,
+    footnotes.order = NULL,
     source_notes.background.color = NULL,
     source_notes.font.size = NULL,
     source_notes.padding = NULL,
@@ -887,7 +905,8 @@ tab_options <- function(
     latex.header_repeat = NULL,
     latex.toprule = NULL,
     latex.bottomrule = NULL,
-    latex.tbl.pos = NULL
+    latex.tbl.pos = NULL,
+    latex.unicode_conversion = NULL
 ) {
 
   # Perform input object validation
