@@ -111,12 +111,12 @@ latex_group_row <- function(
 
   # The width of the group row should be that of the entire table
   tab_width <- colwidth_df$tbl_width[1L]
-  use_width <- if (is.na(tab_width)) "l" else sprintf(">{\\raggedright\\arraybackslash}m{%s}", tab_width)
+  use_width <- ifelse(is.na(tab_width), "l", sprintf(">{\\raggedright\\arraybackslash}m{%s}", tab_width))
 
   if (is.na(group_name)) {
-    row_txt <- paste0("\\multicolumn{", n_cols, "}{", use_width, "}{\\rule{0pt}{0pt}} \\\\[-3.2ex] \n")
+    row_txt <- paste0(latex_multicolumn_cell("\\rule{0pt}{0pt}", alignment = use_width, width = n_cols, override_alignment = FALSE)," \\\\[-3.2ex] \n")
   } else {
-    row_txt <- paste0("\\multicolumn{", n_cols, "}{", use_width, "}{", group_name, "} \\\\[2.5pt] \n")
+    row_txt <- paste0(latex_multicolumn_cell(group_name, alignment = use_width, width = n_cols, override_alignment = FALSE)," \\\\[2.5pt] \n")
   }
 
   paste0(
@@ -236,8 +236,21 @@ create_table_start_l <- function(data, colwidth_df) {
   # Add borders to the right of any columns in the stub
   if (length(stub_layout) > 0) {
 
-    col_defs[seq_along(stub_layout)] <-
-      paste0(col_defs[seq_along(stub_layout)], "|")
+    # Count the actual number of stub columns
+    # When we have both group_label and rowname, we have 2 columns
+    # When we have multiple rowname columns but no group_label, count all stub columns
+    if ("group_label" %in% stub_layout && "rowname" %in% stub_layout) {
+      n_stub_cols <- 2  # group_label + one rowname column
+    } else if ("rowname" %in% stub_layout) {
+      n_stub_cols <- sum(colwidth_df_visible$type == "stub")
+    } else if ("group_label" %in% stub_layout) {
+      n_stub_cols <- 1
+    } else {
+      n_stub_cols <- length(stub_layout)
+    }
+
+    col_defs[seq_len(n_stub_cols)] <-
+      paste0(col_defs[seq_len(n_stub_cols)], "|")
   }
 
   # If a table width is specified, add an extra column
@@ -442,8 +455,32 @@ create_heading_component_l <- function(data) {
 #' @noRd
 create_columns_component_l <- function(data, colwidth_df) {
 
+
   # Get vector representation of stub layout
   stub_layout <- get_stub_layout(data = data)
+  n_stub_cols <- 0
+
+  # if exists, get the length of the stub
+  if(length(stub_layout)>0){
+    stub_vars <- dt_boxhead_get_var_stub(data = data)
+    # Get the actual number of stub columns for the header
+    # This determines how many columns the stub header should span
+    if ("group_label" %in% stub_layout && "rowname" %in% stub_layout) {
+      n_stub_cols <- length(stub_vars) + 1  # group_label + all rowname columns
+      # Get stub_df for width calculations
+      stub_df <- dplyr::filter(colwidth_df, type %in% c("row_group","stub")) %>%
+        dplyr::arrange(type)
+    } else if ("rowname" %in% stub_layout) {
+      stub_df <- dplyr::filter(colwidth_df, type == "stub")
+      n_stub_cols <- nrow(stub_df)
+    } else if ("group_label" %in% stub_layout) { # stub columns can exist in the dataset with only groups in the stub-layout.
+      n_stub_cols <- 1
+      stub_df <- dplyr::filter(colwidth_df, type == "row_group")
+    } else {
+      n_stub_cols <- length(stub_layout)
+      stub_df <- dplyr::filter(colwidth_df, type %in% c("stub", "row_group"))
+    }
+  }
 
   styles_tbl <- dt_styles_get(data = data)
 
@@ -464,7 +501,7 @@ create_columns_component_l <- function(data, colwidth_df) {
         dplyr::filter(
           styles_tbl,
           locname == "columns_columns",
-          colname == headings_labels[i]
+          colname == headings_vars[i]
         )
       )
 
@@ -482,40 +519,77 @@ create_columns_component_l <- function(data, colwidth_df) {
         vctrs::vec_slice(styles_tbl, styles_tbl$locname == "stubhead")
       )
 
-    headings_vars <- prepend_vec(headings_vars, "::stub")
-
-    stub_label <- ifelse(
-      length(stubh$label) > 0,
-      apply_cell_styles_l(stubh$label, styles_stubhead),
-      ""
-    )
-
-    if (length(stub_layout) > 1L) {
-      # If stub_layout == 1L, multicolumn is not needed and stub_label is already defined
+    # Get the actual number of stub columns for the header
+    # This determines how many columns the stub header should span
+    if ("group_label" %in% stub_layout && "rowname" %in% stub_layout) {
+      n_stub_cols <- 2  # group_label + rowname
+      # Get stub_df for width calculations
       stub_df <- dplyr::filter(colwidth_df, type %in% c("stub", "row_group"))
-      if (any(stub_df$unspec == 1L)) {
-        width_txt <- "c"
-      } else {
-        width_txt <-
-          sprintf(
-            ">{\\centering\\arraybackslash}m{%s}",
-            create_singlecolumn_width_text_l(
-              pt = sum(stub_df$pt),
-              lw = sum(stub_df$lw)
+    } else if ("rowname" %in% stub_layout) {
+      stub_df <- dplyr::filter(colwidth_df, type == "stub")
+      n_stub_cols <- nrow(stub_df)
+    } else if ("group_label" %in% stub_layout) {
+      n_stub_cols <- 1
+      stub_df <- dplyr::filter(colwidth_df, type == "row_group")
+    } else {
+      n_stub_cols <- length(stub_layout)
+      stub_df <- dplyr::filter(colwidth_df, type %in% c("stub", "row_group"))
+    }
+
+    # Check if we have multiple stubhead labels for multi-column stub
+    stub_vars <- dt_boxhead_get_var_stub(data = data)
+    has_multi_column_stub <- length(stub_vars) > 1 && !any(is.na(stub_vars))
+    has_multiple_labels <- has_multi_column_stub && length(stubh$label) > 1
+
+    if (has_multiple_labels) {
+      # Create individual headers for each stub column
+      # Process in reverse order since prepend_vec adds to the front
+      for (i in rev(seq_along(stubh$label))) {
+        stub_label <- ifelse(
+          length(stubh$label[i]) > 0 && stubh$label[i] != "",
+          apply_cell_styles_l(stubh$label[i], styles_stubhead),
+          ""
+        )
+        headings_vars <- prepend_vec(headings_vars, sprintf("::stub%d", i))
+        headings_labels <- prepend_vec(headings_labels, stub_label)
+      }
+    } else {
+      # Single label spanning all stub columns (current behavior)
+      headings_vars <- prepend_vec(headings_vars, "::stub")
+
+      stub_label <- ifelse(
+        length(stubh$label) > 0,
+        apply_cell_styles_l(stubh$label[1], styles_stubhead),
+        ""
+      )
+
+      if (n_stub_cols > 1L) {
+        # Use multicolumn to span all stub columns
+        if (any(stub_df$unspec == 1L)) {
+          width_txt <- "c"
+        } else {
+          width_txt <-
+            sprintf(
+              ">{\\centering\\arraybackslash}m{%s}",
+              create_singlecolumn_width_text_l(
+                pt = sum(stub_df$pt),
+                lw = sum(stub_df$lw)
+              )
             )
+        }
+
+        stub_label <-
+          latex_multicolumn_cell(
+            stub_label,
+            alignment = width_txt,
+            width = n_stub_cols,
+            override_alignment = FALSE
           )
       }
 
-      stub_label <-
-        sprintf(
-          "\\multicolumn{%d}{%s}{%s}",
-          length(stub_layout),
-          width_txt,
-          stub_label
-        )
-    }
+      headings_labels <- prepend_vec(headings_labels, stub_label)
 
-    headings_labels <- prepend_vec(headings_labels, stub_label)
+    }
   }
 
   header_repeat <- dt_options_get_value(data, "latex_header_repeat")
@@ -543,8 +617,29 @@ create_columns_component_l <- function(data, colwidth_df) {
       )
 
     if (length(stub_layout) > 0) {
+      # Get the actual number of stub columns for spanners
+      if ("group_label" %in% stub_layout && "rowname" %in% stub_layout) {
 
-      stub_matrix <- matrix(nrow = nrow(spanners), ncol = length(stub_layout))
+        # group_label + rowname
+        n_stub_cols <- 2
+
+      } else if ("rowname" %in% stub_layout) {
+
+        stub_df_cols <- dplyr::filter(colwidth_df, type == "stub")
+        n_stub_cols <- nrow(stub_df_cols)
+
+      } else if ("group_label" %in% stub_layout) {
+
+        n_stub_cols <- 1
+
+      } else {
+
+        n_stub_cols <- length(stub_layout)
+      }
+
+      stub_matrix <- matrix(nrow = nrow(spanners), ncol = n_stub_cols)
+      # retain stub names
+      colnames(stub_matrix) <- stub_df$var
 
       spanners <- cbind(stub_matrix, spanners)
       spanner_ids <- cbind(stub_matrix, spanner_ids)
@@ -560,6 +655,7 @@ create_columns_component_l <- function(data, colwidth_df) {
       # We need a parallel vector of spanner labels and this could
       # be part of the `spanners_rle` list
       spanners_rle$labels <- spanners_i[cumsum(spanners_rle$lengths)]
+      col_order  <- data.frame(var = colnames(spanner_ids))
       spanners_rle <- apply_spanner_styles_l(spanners_rle, styles_tbl)
 
       begins <- (cumsum(utils::head(c(0, spanners_rle$lengths), -1)) + 1)[!is.na(spanners_rle$values)]
@@ -568,10 +664,9 @@ create_columns_component_l <- function(data, colwidth_df) {
 
       is_spanner_na <- is.na(spanners_rle$values)
       is_spanner_single <- spanners_rle$lengths == 1
-
       firsts <- utils::head(cumsum(c(1L, spanners_rle$lengths)), -1L)
       lasts <- cumsum(spanners_rle$lengths)
-      span_widths <- calculate_multicolumn_width_text_l(begins = firsts, ends = lasts, colwidth_df = colwidth_df)
+      span_widths <- calculate_multicolumn_width_text_l(begins = firsts, ends = lasts, col_order = col_order ,colwidth_df = colwidth_df)
       tex_widths <-
         ifelse(
           nzchar(span_widths),
@@ -579,27 +674,61 @@ create_columns_component_l <- function(data, colwidth_df) {
           "c"
         )
 
-      multicol <-
-        ifelse(
-          is_spanner_na, "",
-          ifelse(
-            is_spanner_single, spanners_rle$labels,
-            sprintf(
-              "\\multicolumn{%d}{%s}{%s}",
-              spanners_rle$lengths,
-              tex_widths,
-              spanners_rle$labels
-            )
+
+      multicol <- sapply(seq_along(spanners_rle$values),function(spanner_idx){
+
+
+        if(is.na(spanners_rle$values[[spanner_idx]])){
+          ""
+        }else{
+
+          span_label <- spanners_rle$labels[[spanner_idx]]
+          span_length <- spanners_rle$lengths[[spanner_idx]]
+
+          if(grepl("\\shortstack",span_label, fixed = TRUE)){
+            if( tex_widths[[spanner_idx]] == "c"){
+              span_label <- shortstack_alignment(span_label, alignment = "center")
+            }
+          }
+
+          latex_multicolumn_cell(
+            x = span_label,
+            alignment = tex_widths[[spanner_idx]],
+            width = span_length,
+            override_width = TRUE,
+            override_alignment = FALSE
           )
-        )
+        }
+      })
 
-      # If there is a stub we need to tweak the spanners row with a blank
-      # multicolumn statement that's the same width as that in the columns
-      # row; this is to prevent the automatic vertical line that would otherwise
-      # appear here
-      if (length(stub_layout) > 1L) {
 
-        tex_stub_width <- calculate_multicolumn_width_text_l(begins = 1, ends = 2, colwidth_df = colwidth_df)
+      # If there is a stub we need to tweak the spanners row with a blank multicolumn
+      # statement that's the same width as that in the columns row; this is to
+      # prevent the automatic vertical line that would otherwise appear here
+
+      # Get the actual number of stub columns
+      if ("group_label" %in% stub_layout && "rowname" %in% stub_layout) {
+
+        # group_label + rowname
+        n_stub_cols <- 2
+
+      } else if ("rowname" %in% stub_layout) {
+
+        stub_df_cols <- dplyr::filter(colwidth_df, type == "stub")
+        n_stub_cols <- nrow(stub_df_cols)
+
+      } else if ("group_label" %in% stub_layout) {
+
+        n_stub_cols <- 1
+
+      } else {
+
+        n_stub_cols <- length(stub_layout)
+      }
+
+      if (n_stub_cols > 1L) {
+
+        tex_stub_width <- calculate_multicolumn_width_text_l(begins = 1, ends = n_stub_cols,  col_order = col_order, colwidth_df = colwidth_df)
         if (tex_stub_width == "") {
           mc_stub <- "l"
         } else {
@@ -608,8 +737,8 @@ create_columns_component_l <- function(data, colwidth_df) {
 
         multicol <-
           c(
-            sprintf("\\multicolumn{%d}{%s}{}", length(stub_layout), mc_stub),
-            multicol[-seq_along(stub_layout)]
+            sprintf("\\multicolumn{%d}{%s}{}", n_stub_cols, mc_stub),
+            multicol[-seq_len(n_stub_cols)]
           )
       }
 
@@ -661,6 +790,61 @@ create_body_component_l <- function(data, colwidth_df) {
   # Get the number of rows in the body
   n_rows <- nrow(cell_matrix)
 
+  # Apply hierarchical stub merging for multiple stub columns
+  # (hide repeated values in all columns except the rightmost)
+  if (has_stub_column) {
+    stub_vars <- dt_boxhead_get_var_stub(data = data)
+
+    if (length(stub_vars) > 1 && !any(is.na(stub_vars))) {
+
+      # Get original body data to check for consecutive repeating values
+      original_body <- dt_data_get(data = data)
+
+      # Process all stub columns except the rightmost one
+      hierarchy_vars <- stub_vars[-length(stub_vars)]
+      stub_matrix <- as.matrix(original_body[, hierarchy_vars, drop = FALSE])
+
+      # Determine which columns to hide based on hierarchical grouping
+      for (col_idx in seq_along(hierarchy_vars)) {
+
+        # Position in cell_matrix (accounting for group_label column if present)
+        matrix_col_idx <- col_idx
+        if ("group_label" %in% stub_layout) {
+          matrix_col_idx <- col_idx + 1
+        }
+
+        for (row_idx in 2:n_rows) {
+          should_hide <- TRUE
+
+          # Check if current value matches previous value (handle NAs properly)
+          curr_val <- stub_matrix[row_idx, col_idx]
+          prev_val <- stub_matrix[row_idx - 1, col_idx]
+
+          if (!identical(curr_val, prev_val)) {
+            should_hide <- FALSE
+          }
+
+          # Also check that all columns to the left match
+          if (should_hide && col_idx > 1) {
+            for (left_col_idx in 1:(col_idx - 1)) {
+              curr_left <- stub_matrix[row_idx, left_col_idx]
+              prev_left <- stub_matrix[row_idx - 1, left_col_idx]
+              if (!identical(curr_left, prev_left)) {
+                should_hide <- FALSE
+                break
+              }
+            }
+          }
+
+          # Hide the value by making it empty if conditions are met
+          if (should_hide) {
+            row_splits_body[[row_idx]][matrix_col_idx] <- ""
+          }
+        }
+      }
+    }
+  }
+
   if ("group_label" %in% stub_layout) {
 
     for (i in seq_len(nrow(groups_rows_df))) {
@@ -1011,7 +1195,20 @@ summary_rows_for_group_l <- function(
         row_splits_summary,
         function(x) {
           x <- c("", x)
-          x[1:2] <- paste0("\\multicolumn{1}{l|}{", x[1:2], "}")
+          x[1] <- latex_multicolumn_cell(
+            x = x[1],
+            alignment = "l|",
+            width = 1,
+            override_width = TRUE,
+            override_alignment = FALSE
+          )
+          x[2] <- latex_multicolumn_cell(
+            x = x[2],
+            alignment = "l|",
+            width = 1,
+            override_width = TRUE,
+            override_alignment = FALSE
+          )
           x
         }
       )
@@ -1106,22 +1303,33 @@ create_footer_component_l <- function(data) {
 
     footnotes_tbl <- dplyr::distinct(footnotes_tbl, fs_id, footnotes)
 
+    footnote_marks <- footnote_mark_to_latex(
+      data = data,
+      mark = footnotes_tbl[["fs_id"]],
+      location = "ftr"
+    )
+
     # Create a vector of formatted footnotes
     footnotes <-
-      paste0(
-        footnote_mark_to_latex(
-          data = data,
-          mark = footnotes_tbl[["fs_id"]],
-          location = "ftr"
-        ),
-        vapply(
-          footnotes_tbl[["footnotes"]],
-          FUN.VALUE = character(1L),
-          #FUN = process_text,
-          FUN = function(x, context, styles_obj) apply_cell_styles_l(process_text(x, context = context), styles_obj),
-          context = "latex",
-          styles_obj = styles_footnote
-        )
+      vapply(
+        seq_along(footnotes_tbl[["footnotes"]]),
+        FUN.VALUE = character(1L),
+        #FUN = process_text,
+        FUN = function(idx,
+                       footnotes,
+                       footnote_marks,
+                       context,
+                       styles_obj) {
+          apply_cell_styles_l(
+             paste(footnote_marks[[idx]], process_text(footnotes[[idx]], context = context)),
+            styles_obj,
+            type = "footnote"
+            )
+        },
+        footnotes = footnotes_tbl[["footnotes"]],
+        footnote_marks = footnote_marks,
+        context = "latex",
+        styles_obj = styles_footnote
       )
 
 
@@ -1150,7 +1358,7 @@ create_footer_component_l <- function(data) {
         dplyr::filter(dt_styles_get(data), locname == "source_notes")
       )
 
-    source_notes <- apply_cell_styles_l(source_notes, styles_source)
+    source_notes <- apply_cell_styles_l(source_notes, styles_source, type = "footnote")
 
   } else {
     source_notes <- ""
@@ -1158,7 +1366,7 @@ create_footer_component_l <- function(data) {
 
   # Create the footer block
   paste0(
-    "\\begin{minipage}{\\linewidth}\n",
+    "\\begin{minipage}{\\linewidth}\n\\vspace{.05em}\n",
     paste0(footnotes, source_notes),
     "\\end{minipage}\n",
     collapse = ""
@@ -1182,14 +1390,21 @@ create_body_rows_l <- function(
 
   stub_is_2 <- length(stub_layout) > 1L
 
+  # Get the actual stub column variables to determine how many stub columns we have
+  stub_vars <- dt_boxhead_get_var_stub(data = data)
+  n_stub_cols <- if (length(stub_vars) == 1 && is.na(stub_vars)) 0 else length(stub_vars)
+
   if (is.null(stub_layout)) {
     vars <- default_vars
   } else if (!is.null(stub_layout) && !stub_is_2 && stub_layout == "rowname") {
-    vars <- c("::stub::", default_vars)
+    # Create a ::stub:: placeholder for each stub column
+    vars <- c(rep("::stub::", n_stub_cols), default_vars)
   } else if (!is.null(stub_layout) && !stub_is_2 && stub_layout == "group_label") {
     vars <- c("::group::", default_vars)
   } else if (!is.null(stub_layout) && stub_is_2) {
-    vars <- c("::group::", "::stub::", default_vars)
+    # When we have both group_label and rowname columns
+    # Create a ::stub:: placeholder for each stub column, plus the group column
+    vars <- c("::group::", rep("::stub::", n_stub_cols), default_vars)
   }
 
   if ("::group::" %in% vars) {
@@ -1219,6 +1434,7 @@ create_body_rows_l <- function(
               colname_i <- vars[i]
 
               if (
+                !is.na(colname_i) &&
                 colname_i == "::group::" &&
                 "row_groups" %in% styles_tbl_i[["locname"]]
               ) {
@@ -1227,6 +1443,7 @@ create_body_rows_l <- function(
                 #styles_i_col <- styles_tbl_i_col[["styles"]]
 
               } else if (
+                !is.na(colname_i) &&
                 colname_i == "::stub::" &&
                 "stub" %in% styles_tbl_i[["locname"]]
               ) {
@@ -1236,6 +1453,7 @@ create_body_rows_l <- function(
 
               } else if (
                 "data" %in% styles_tbl_i[["locname"]] &&
+                !is.na(colname_i) &&
                 colname_i %in% styles_tbl_i[["colname"]]
               ) {
 
@@ -1317,7 +1535,13 @@ create_summary_rows_l <- function(
 
   # Get vector representation of stub layout
   stub_layout <- get_stub_layout(data = data)
-  stub_width <- length(stub_layout)
+
+  # Get the actual number of stub columns (including multiple rowname columns)
+  stub_vars <- dt_boxhead_get_var_stub(data = data)
+  stub_width <- if (length(stub_vars) == 1 && is.na(stub_vars)) 0 else length(stub_vars)
+  if ("group_label" %in% stub_layout) {
+    stub_width <- stub_width + 1
+  }
 
   # Obtain all of the visible (`"default"`), non-stub
   # column names for the table
@@ -1365,8 +1589,9 @@ create_summary_rows_l <- function(
 
                   x <- c(rep("", stub_width - 1), x)
 
-                  x[seq_len(stub_width)] <-
-                    paste0("\\multicolumn{1}{l|}{", x[seq_len(stub_width)], "}")
+                  x[seq_len(stub_width)] <- sapply(x[seq_len(stub_width)], function(x) {
+                    latex_multicolumn_cell(x, width = 1, alignment = "l|", override_alignment = FALSE)
+                    })
 
                   x
                 }
@@ -1508,7 +1733,7 @@ consolidate_cell_styles_l <- function(styles_df) {
 #' a cell of text to be output in LaTeX.
 #'
 #' @noRd
-apply_cell_styles_l <- function(content, style_obj) {
+apply_cell_styles_l <- function(content, style_obj, type = "cell") {
 
   # Set default values for no footnote present
   just_content <- content
@@ -1528,19 +1753,23 @@ apply_cell_styles_l <- function(content, style_obj) {
     x <- .apply_style_fill_l(x, style_obj)
     x <- .apply_style_transform_l(x, style_obj)
     x <- .apply_style_decorate_l(x, style_obj)
+    x <- .apply_style_alignment_shortstack(x, style_obj)
 
     # Apply changes that can be made to the bracketed environment
-    out_text <- paste0(
-      "{",
-
-      .apply_style_style_l(style_obj),
-      .apply_style_weight_l(style_obj),
-      # Can generate "\small for example
-      .apply_style_fontsize_l(style_obj),
-      .apply_style_indentation_l(style_obj),
-      x,
-      "}"
-    )
+    out_text <- .apply_style_cell_alignment(
+        paste0(
+          "{",
+          .apply_style_style_l(style_obj),
+          .apply_style_weight_l(style_obj),
+          # Can generate "\small for example
+          .apply_style_fontsize_l(style_obj),
+          .apply_style_indentation_l(style_obj),
+          x,
+          "}"
+        ),
+        style_obj,
+        type = type
+      )
   } else {
     out_text <- just_content
   }
@@ -1610,6 +1839,111 @@ apply_cell_styles_l <- function(content, style_obj) {
 
 }
 
+.apply_style_alignment_shortstack <- function(x, style_obj) {
+
+  if(!grepl("\\shortstack[l]", x, fixed = TRUE)){return(x)}
+
+  alignment <- style_obj[["cell_text"]][["align"]]
+
+  if(is.null(alignment) | identical(alignment, "left")){
+    return(x)
+  }
+
+  shortstack_alignment(x, alignment = alignment)
+}
+
+shortstack_alignment <- function(x, alignment){
+
+  shortstackalignment <- c(
+    "center" = "[c]",
+    "justify" = "[c]",
+    "left" = "[l]",
+    "right" = "[r]"
+  )[alignment]
+
+  gsub("\\shortstack[l]",paste0("\\shortstack",shortstackalignment), x, fixed = TRUE)
+}
+
+.apply_style_cell_alignment <- function(x, style_obj, type = "cell") {
+
+  if (is.null(style_obj[["cell_text"]][["align"]])) return(x)
+
+  alignment <- style_obj[["cell_text"]][["align"]]
+
+  if(type == "cell"){
+    alignment <- c(
+      "center" = "c",
+      "justify" = "c",
+      "left" = "l",
+      "right" = "r"
+    )[alignment]
+
+    latex_multicolumn_cell(x, alignment = alignment, width = 1)
+  }else if(type == "footnote"){
+    latex_align_text(x, alignment = alignment)
+  }
+}
+
+latex_multicolumn_cell <- function(x,  width = NULL, alignment = NULL, override_width = TRUE, override_alignment = TRUE){
+
+  if (grepl("\\multicolumn", x, fixed = TRUE)) {
+    pre_existing <- TRUE
+    existing_width <- gsub(".*(\\multicolumn)\\{(\\d+)\\}\\{(.*?)\\}\\{.+\\}", "\\2", x)
+    if(existing_width == ""){
+      existing_width <- NULL
+    }
+    existing_alignment <- gsub(".*(\\multicolumn)\\{(\\d+)\\}\\{(.*?)\\}\\{.+\\}", "\\3", x)
+    if(existing_width == ""){
+      existing_width <- NULL
+    }
+  } else{
+    pre_existing <- FALSE
+    existing_width <- NULL
+    existing_alignment <- NULL
+  }
+
+  if(override_width){
+    width <- width %||% existing_width
+  }else{
+    width <- existing_width %||% width
+  }
+
+  if(override_alignment){
+    alignment <- alignment %||% existing_alignment
+  }else{
+    alignment <- existing_alignment %||% alignment
+  }
+
+  new_multicolumn_statement <- paste0("\\multicolumn{",width,"}{",alignment,"}")
+
+  if(pre_existing){
+    gsub(paste0("\\multicolumn{",existing_width,"}{",existing_alignment,"}"), new_multicolumn_statement, x, fixed = TRUE)
+  }else{
+    paste0(new_multicolumn_statement,"{",x,"}")
+  }
+}
+
+latex_cleanup_multicolumn <- function(x){
+  ## Fix missing alignment
+  x <- gsub("(\\multicolumn\\{(\\d+)\\})\\{\\}(\\{.+?\\})", "\\1{l}\\2", x)
+  ## Fix missing column width
+  x <- gsub("(\\multicolumn)\\{\\}(\\{.+?\\}\\{.+?\\})", "\\1{1}\\2", x)
+  x
+}
+
+latex_align_text <- function(x, alignment){
+
+  alignment <- c(
+    "center" = "\\centering",
+    "justify" = "\\sloppy\\setlength\\parfillskip{0pt}",
+    "left" = "\\raggedright",
+    "right" = "\\raggedleft"
+  )[alignment]
+
+  paste0("\\parbox{\\linewidth}{",alignment," ",x,"}")
+
+}
+
 .apply_style_fontsize_l <- function(style_obj) {
 
   if (is.null(style_obj[["cell_text"]][["size"]])) return("")
@@ -1742,6 +2076,7 @@ create_colwidth_df_l <- function(data) {
 
   n <- dim(boxhead)[1L]
   width_df <- data.frame(
+    var = boxhead$var,
     type = boxhead$type,
     unspec = rep.int(0L, n),
     lw = rep.int(0L, n),
@@ -1815,10 +2150,17 @@ create_colwidth_df_l <- function(data) {
   width_df
 }
 
-calculate_multicolumn_width_text_l <- function(begins, ends, colwidth_df) {
-
+calculate_multicolumn_width_text_l <- function(begins, ends, col_order, colwidth_df) {
   out_text <- rep("", times = length(begins))
 
+  # order by column order to ensure correct columns are used
+  # this is important if data order has changed, or there are hidden columns etc
+  colwidth_df <- col_order %>%
+    dplyr::left_join(colwidth_df, by = "var") %>%
+    dplyr::filter(type != "hidden" )
+
+
+
   for (i in seq_along(begins)) {
     ind <- seq(from = begins[i], to = ends[i])
 
