@@ -34,6 +34,9 @@ resolve_footnotes_styles <- function(data, tbl_type) {
   # Get the `footnote_marks` option from the options table
   footnote_marks <- dt_options_get_value(data = data, option = "footnotes_marks")
 
+  # Get the `footnote_order` option from the options table
+  footnote_order <- dt_options_get_value(data = data, option = "footnotes_order")
+
   rlang::arg_match0(tbl_type, c("footnotes", "styles"))
 
   if (tbl_type == "footnotes") {
@@ -116,50 +119,59 @@ resolve_footnotes_styles <- function(data, tbl_type) {
     tbl_not_data <- tbl[!data_cond, ]
 
     tbl_data <- tbl[data_cond, ]
-    
+
     if (nrow(tbl_data) > 0L) {
 
-      # Re-map the `rownum` to the new row numbers for the
-      # data rows
-      tbl_data$rownum <- rownum_translation(
-        body = body,
-        rownum_start = tbl_data$rownum)
+      # Re-map the `rownum` to the new row numbers for the data rows
+      tbl_data$rownum <-
+        rownum_translation(
+          body = body,
+          rownum_start = tbl_data$rownum
+        )
 
       # Add a `colnum` column that's required for
       # arranging `tbl` in such a way that the order
       # of records moves from top-to-bottom, left-to-right
-      
+
       # For stub footnotes, we need to set colnum based on the position
       # of each stub column (leftmost = most negative)
       tbl_data$colnum <- rep(NA_integer_, nrow(tbl_data))
-      
+
       # Handle stub footnotes
       stub_mask <- tbl_data$locname == "stub"
-      
+
       if (any(stub_mask)) {
+
         # Get stub columns in order
         stub_cols <- dt_boxhead_get_var_by_type(data = data, type = "stub")
-        
+
         for (i in which(stub_mask)) {
+
           colname <- tbl_data$colname[i]
-          
+
           if (is.na(colname)) {
+
             # Traditional stub footnotes without specific column
             tbl_data$colnum[i] <- 0L
+
           } else {
+
             # Find position of this column in stub columns
             stub_pos <- match(colname, stub_cols)
-            
+
             if (is.na(stub_pos)) {
+
               tbl_data$colnum[i] <- 0L  # fallback
+
             } else {
+
               # Make leftmost column most negative
               tbl_data$colnum[i] <- -(length(stub_cols) - stub_pos + 1)
             }
           }
         }
       }
-      
+
       # Handle data footnotes
       data_mask <- tbl_data$locname == "data"
       if (any(data_mask)) {
@@ -237,11 +249,13 @@ resolve_footnotes_styles <- function(data, tbl_type) {
     tbl_not_g_summary_cells <- tbl[cond, ]
 
     tbl_g_summary_cells <- tbl[!cond, ]
-    tbl_g_summary_cells$colnum <- colname_to_colnum(
-      data = data,
-      colname = tbl_g_summary_cells$colname,
-      missing_is_zero = TRUE
-    )
+
+    tbl_g_summary_cells$colnum <-
+      colname_to_colnum(
+        data = data,
+        colname = tbl_g_summary_cells$colname,
+        missing_is_zero = TRUE
+      )
 
     # Re-combine `tbl_not_g_summary_cells`
     # with `tbl_g_summary_cells`
@@ -267,7 +281,9 @@ resolve_footnotes_styles <- function(data, tbl_type) {
       colname = default_vars,
       rownum = -1L
     )
-    tbl_column_cells <- dplyr::inner_join(tmp, default_variables, by = "colname")
+
+    tbl_column_cells <-
+      dplyr::inner_join(tmp, default_variables, by = "colname")
 
     # Re-combine `tbl_not_column_cells`
     # with `tbl_column_cells`
@@ -364,6 +380,7 @@ resolve_footnotes_styles <- function(data, tbl_type) {
 
   # For styles, sort the table rows by the standard order
   if (tbl_type == "styles") {
+
     order_of_tbl <- order(tbl$locnum, tbl$rownum, tbl$colnum)
     tbl <- tbl[order_of_tbl, , drop = FALSE]
   }
@@ -372,22 +389,27 @@ resolve_footnotes_styles <- function(data, tbl_type) {
   # column with footnote marks
   if (tbl_type == "footnotes") {
 
-    # Sort all footnotes by visual position: locnum, rownum, colnum
-    # This ensures left-to-right, top-to-bottom ordering of footnote marks
-    # since we've already set proper colnum values for stub footnotes
-    if (nrow(tbl) > 0L) {
-      order_of_tbl <- order(tbl$locnum, tbl$rownum, tbl$colnum, na.last = TRUE)
-      tbl <- tbl[order_of_tbl, , drop = FALSE]
+    # Don't sort if order is preserved
+    if (footnote_order != "preserve_order") {
+
+      # Sort all footnotes by visual position: locnum, rownum, colnum
+      # This ensures left-to-right, top-to-bottom ordering of footnote marks
+      # since we've already set proper colnum values for stub footnotes
+      if (nrow(tbl) > 0L) {
+        order_of_tbl <- order(tbl$locnum, tbl$rownum, tbl$colnum, na.last = TRUE)
+        tbl <- tbl[order_of_tbl, , drop = FALSE]
+      }
     }
 
     # Generate a lookup table with ID'd footnote
     # text elements (that are distinct) but preserve the sorted order
     footnotes_ordered <- tbl[tbl$locname != "none", "footnotes", drop = FALSE]
-    
+
     # Create a lookup table that preserves the order from the sorted table
     # Use the order of first appearance in the sorted table
-    lookup_tbl <- footnotes_ordered[!duplicated(footnotes_ordered$footnotes), , drop = FALSE]
-    
+    lookup_tbl <-
+      footnotes_ordered[!duplicated(footnotes_ordered$footnotes), , drop = FALSE]
+
     # Assign fs_id based on the order in the sorted table (1, 2, 3, ...)
     lookup_tbl$fs_id <- as.character(seq_len(nrow(lookup_tbl)))
 
@@ -409,7 +431,30 @@ resolve_footnotes_styles <- function(data, tbl_type) {
         tbl$fs_id <- process_footnote_marks(tbl$fs_id, marks = footnote_marks)
       }
 
-      tbl <- vctrs::vec_rbind(tbl_no_loc, tbl)
+      if (footnote_order == "marks_first") {
+
+        tbl <- vctrs::vec_rbind(tbl, tbl_no_loc)
+
+      } else if (footnote_order == "preserve_order") {
+
+        footnotes_all <- vctrs::vec_rbind(tbl_no_loc, tbl)
+
+        # get original order from data
+        order <- dplyr::select(data$`_footnotes`, locname, footnotes)
+
+        # sort by original order
+        tbl <-
+          dplyr::left_join(
+            order,
+            footnotes_all,
+            by = c("locname", "footnotes")
+          ) |>
+          dplyr::select(names(footnotes_all))
+
+      } else {
+
+        tbl <- vctrs::vec_rbind(tbl_no_loc, tbl)
+      }
     }
   }
 
@@ -458,6 +503,7 @@ set_footnote_marks_columns <- function(data, context = "html") {
           fs_id_coalesced = paste(sort(fs_id), collapse = ","),
           .by = "grpname"
         )
+
       footnotes_columns_group_marks <-
         dplyr::distinct(
           footnotes_columns_group_marks,
@@ -621,19 +667,27 @@ apply_footnotes_to_output <- function(data, context = "html") {
 
       # For stub footnotes with NA colname, this indicates legacy usage
       # where footnotes should be applied to all stub columns
-      na_colname_indices <- which(is.na(footnotes_tbl_data$colname) & footnotes_tbl_data$locname == "stub")
-      
+      na_colname_indices <-
+        which(
+          is.na(footnotes_tbl_data$colname) &
+          footnotes_tbl_data$locname == "stub"
+        )
+
       if (length(na_colname_indices) > 0) {
+
         # For multi-column stubs, legacy footnotes (without specific columns)
-        # should only be applied to the first stub column for backward compatibility
+        # should only be applied to the first stub column for
+        # backward compatibility
         footnotes_tbl_data$colname[na_colname_indices] <- boxhead_var_stub[1]
       }
     }
 
     # Ensure fs_id column exists (it should be added by resolve_footnotes_styles)
     if (!"fs_id" %in% names(footnotes_tbl_data)) {
+
       # Add a temporary fs_id based on row numbers as fallback
-      footnotes_tbl_data$fs_id <- as.character(seq_len(nrow(footnotes_tbl_data)))
+      footnotes_tbl_data$fs_id <-
+        as.character(seq_len(nrow(footnotes_tbl_data)))
     }
 
     footnotes_data_marks <-
@@ -650,7 +704,11 @@ apply_footnotes_to_output <- function(data, context = "html") {
         }
       )
     footnotes_data_marks <-
-      dplyr::distinct(footnotes_data_marks, colname, rownum, locname, placement, fs_id_coalesced, .keep_all = TRUE)
+      dplyr::distinct(
+        footnotes_data_marks, colname, rownum, locname,
+        placement, fs_id_coalesced,
+        .keep_all = TRUE
+      )
 
     # Get the correct footnote rendering functions
     withCallingHandlers(
@@ -661,6 +719,7 @@ apply_footnotes_to_output <- function(data, context = "html") {
       apply_footnotes_method[[context]],
       error = function(e) cli::cli_abort("Can't find the correct rendering function for footnotes for context = {.val {context}}", parent = e)
     )
+
     for (i in seq_len(nrow(footnotes_data_marks))) {
 
       text <-
@@ -710,17 +769,23 @@ place_footnote_on_left <- function(text, mark, context) {
         mark, "\U000A0",
         gsub("<div class='gt_from_md'><p>", "", text, fixed = TRUE)
       )
+
   } else if (context == "html" && startsWith(text, "<div data-qmd-base64")) {
+
     # FIXME #1773, figure out how to tweak the regex (in Quarto)
     text <- paste(mark, text, sep = "\U000A0")
 
   } else if (context == "word" || context == "latex") {
+
     text <- apply_footnotes_method[[context]](text, mark, position = "left")
+
   } else if (context == "html" || context == "grid") {
+
     # Footnote placement on the left of the cell text; ensure that a
     # non-breaking space (added here as Unicode's 'NO-BREAK SPACE',
     # "U+00A0") separates the marks from the text content
     text <- paste(mark, text, sep = "\U000A0")
+
   } else if (context == "rtf") {
     text <- paste(mark, text)
   }
@@ -729,6 +794,7 @@ place_footnote_on_left <- function(text, mark, context) {
 }
 
 place_footnote_on_right <- function(text, mark, context) {
+
   # Footnote placement on the right of the cell text
   if (context != "html") {
     return(apply_footnotes_method[[context]](text, mark))
@@ -744,12 +810,16 @@ place_footnote_on_right <- function(text, mark, context) {
       )
 
   } else if (endsWith(text, "</p>\n</div></div>")) {
+
     # Processing html (This code may not be valid as of #1860)
     # FIXME possibly the place where we could fix #1773
     text <- apply_footnotes_method[[context]](text, mark)
+
   } else {
+
     text <- apply_footnotes_method[[context]](text, mark)
   }
+
   text
 }
 
@@ -771,8 +841,10 @@ set_footnote_marks_row_groups <- function(data, context = "html") {
         fs_id_coalesced = paste(sort(fs_id), collapse = ","),
         .by = "grpname"
       )
+
     # will only remain
-    footnotes_row_groups_marks <- dplyr::distinct(footnotes_row_groups_marks, fs_id_coalesced, grpname)
+    footnotes_row_groups_marks <-
+      dplyr::distinct(footnotes_row_groups_marks, fs_id_coalesced, grpname)
 
     for (i in seq_len(nrow(footnotes_row_groups_marks))) {
 
@@ -803,6 +875,7 @@ apply_footnotes_to_summary <- function(data, context = "html") {
 
   list_of_summaries <- dt_summary_df_get(data = data)
   footnotes_tbl <- dt_footnotes_get(data = data)
+
   # make sure rownames are recognized to add footnote marks
   # to cells_stub_grand_summary() / cells_stub_summary() #1832
   # dplyr::coalesce()
