@@ -3,7 +3,7 @@ test_that("gt_preview() works correctly", {
   # Ensure that gt objects still work with `gt_preview()`
   expect_s3_class(
     gt_preview(mtcars),
-    gt_preview(mtcars %>% gt()) %>% class(),
+    gt_preview(mtcars |> gt()) |> class(),
     exact = TRUE
   )
 
@@ -14,22 +14,22 @@ test_that("gt_preview() works correctly", {
   output_tbl <- dt_body_get(built_tbl)
 
   # Expect that the output table has had rows removed
-  nrow(mtcars) %>% expect_gt(nrow(output_tbl))
+  nrow(mtcars) |> expect_gt(nrow(output_tbl))
 
   # Expect certain row names in `data_df`
   expect_equal(output_tbl$rowname, c("1", "2", "3", "4", "5", "6..31", "32"))
 
   # Expect mostly empty strings in the ellipsis row
   # (row `6` in this case)
-  output_tbl[6, ] %>%
-    unlist() %>%
-    unname() %>%
+  output_tbl[6, ] |>
+    unlist() |>
+    unname() |>
     expect_equal(c("6..31", rep("", ncol(mtcars))))
 
   # Create a preview table with non-default `top_n` and `bottom_n` values
   gt_tbl <- gt_preview(mtcars, top_n = 10, bottom_n = 5)
 
-  built_tbl <- gt_tbl %>% build_data(context = "html")
+  built_tbl <- gt_tbl |> build_data(context = "html")
   output_tbl <- dt_body_get(data = built_tbl)
 
   # Expect a preview of the `mtcars` dataset with different `top_n`
@@ -41,9 +41,9 @@ test_that("gt_preview() works correctly", {
   )
 
   # Expect empty strings in the ellipsis row (row `11` in this case)
-  output_tbl[11, ] %>%
-    unlist() %>%
-    unname() %>%
+  output_tbl[11, ] |>
+    unlist() |>
+    unname() |>
     expect_equal(c("11..27", rep("", ncol(mtcars))))
 
   # Create a preview table with a 5-row version of `mtcars`
@@ -84,7 +84,7 @@ test_that("gt_preview() works correctly", {
   # Create a preview table that doesn't include row numbers
   gt_tbl <- gt_preview(mtcars, incl_rownums = FALSE)
 
-  built_tbl <- gt_tbl %>% build_data(context = "html")
+  built_tbl <- gt_tbl |> build_data(context = "html")
   output_tbl <- dt_body_get(data = built_tbl)
 
   # Expect the column names to be equal to that of the
@@ -102,6 +102,18 @@ test_that("gt_preview() works correctly", {
   expect_no_error(gt_preview(sp500))
   expect_no_error(gt_preview(pizzaplace))
   expect_no_error(gt_preview(exibble))
+  expect_no_error(gt_preview(towny))
+  expect_no_error(gt_preview(peeps))
+  expect_no_error(gt_preview(films))
+  expect_no_error(gt_preview(metro))
+  expect_no_error(gt_preview(gibraltar))
+  expect_no_error(gt_preview(constants))
+  expect_no_error(gt_preview(illness))
+  expect_no_error(gt_preview(reactions))
+  expect_no_error(gt_preview(photolysis))
+  expect_no_error(gt_preview(nuclides))
+  expect_no_error(gt_preview(rx_adsl))
+  expect_no_error(gt_preview(rx_addv))
 
   expect_no_error(gt_preview(datasets::airquality))
   expect_no_error(gt_preview(datasets::cars))
