@@ -1,4 +1,4 @@
-test_that("fmt_currency() works correctly", {
+test_that("fmt_currency() works correctly in LaTeX output tables", {
 
   # Create an input data frame four columns: two
   # character-based and two that are numeric
@@ -20,8 +20,8 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column as USD, use all other defaults;
   # extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
-       fmt_currency(columns = "num_1", currency = "USD") %>%
+    (tbl_latex |>
+       fmt_currency(columns = "num_1", currency = "USD") |>
        render_formats_test(context = "latex"))[["num_1"]],
     c("\\$1,836.23", "\\$2,763.39", "\\$937.29",
       "\\$643.00", "\\$212.23", "\\$0.00",
@@ -31,8 +31,8 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column as USD to 5 decimal places, use all
   # other defaults; extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
-       fmt_currency(columns = "num_1", currency = "USD", decimals = 5) %>%
+    (tbl_latex |>
+       fmt_currency(columns = "num_1", currency = "USD", decimals = 5) |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1,836.23000", "\\$2,763.39000",
       "\\$937.29000", "\\$643.00000",
@@ -44,8 +44,8 @@ test_that("fmt_currency() works correctly", {
   # use all other defaults; extract `output_df` and compare to
   # expected values
   expect_equal(
-    (tbl_latex %>%
-       fmt_currency(columns = "num_1", currency = "USD", use_subunits = FALSE) %>%
+    (tbl_latex |>
+       fmt_currency(columns = "num_1", currency = "USD", use_subunits = FALSE) |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1,836", "\\$2,763", "\\$937",
       "\\$643", "\\$212", "\\$0",
@@ -56,8 +56,8 @@ test_that("fmt_currency() works correctly", {
   # grouping separators, use all other defaults; extract `output_df`
   # and compare to expected values
   expect_equal(
-    (tbl_latex %>%
-       fmt_currency(columns = "num_1", currency = "USD", use_seps = FALSE) %>%
+    (tbl_latex |>
+       fmt_currency(columns = "num_1", currency = "USD", use_seps = FALSE) |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1836.23", "\\$2763.39", "\\$937.29",
       "\\$643.00", "\\$212.23", "\\$0.00",
@@ -68,8 +68,8 @@ test_that("fmt_currency() works correctly", {
   # character as digit grouping separators, use all other defaults;
   # extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
-       fmt_currency(columns = "num_1", currency = "USD", sep_mark = " ") %>%
+    (tbl_latex |>
+       fmt_currency(columns = "num_1", currency = "USD", sep_mark = " ") |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1 836.23", "\\$2 763.39", "\\$937.29",
       "\\$643.00", "\\$212.23", "\\$0.00",
@@ -80,10 +80,10 @@ test_that("fmt_currency() works correctly", {
   # separators and a comma for the decimal mark, use all other defaults;
   # extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
          columns = "num_1", currency = "USD",
-         sep_mark = ".", dec_mark = ",") %>%
+         sep_mark = ".", dec_mark = ",") |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1.836,23", "\\$2.763,39", "\\$937,29",
       "\\$643,00", "\\$212,23", "\\$0,00",
@@ -94,9 +94,9 @@ test_that("fmt_currency() works correctly", {
   # values, use all other defaults; extract `output_df` and compare
   # to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "USD", accounting = TRUE) %>%
+         columns = "num_1", currency = "USD", accounting = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1,836.23", "\\$2,763.39", "\\$937.29",
       "\\$643.00", "\\$212.23", "\\$0.00",
@@ -107,9 +107,9 @@ test_that("fmt_currency() works correctly", {
   # values, use all other defaults; apply the default context, extract
   # `output_df`, and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "USD", accounting = TRUE) %>%
+         columns = "num_1", currency = "USD", accounting = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1,836.23", "\\$2,763.39", "\\$937.29",
       "\\$643.00", "\\$212.23", "\\$0.00",
@@ -120,10 +120,10 @@ test_that("fmt_currency() works correctly", {
   # 1/1000, use all other defaults; extract `output_df` and compare
   # to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
          columns = "num_1", currency = "USD",
-         decimals = 4, scale_by = 1/1000) %>%
+         decimals = 4, scale_by = 1/1000) |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1.8362", "\\$2.7634", "\\$0.9373",
       "\\$0.6430", "\\$0.2122", "\\$0.0000",
@@ -134,9 +134,9 @@ test_that("fmt_currency() works correctly", {
   # different literals, use all other defaults; extract `output_df` and
   # compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "USD", pattern = "a {x} b") %>%
+         columns = "num_1", currency = "USD", pattern = "a {x} b") |>
        render_formats_test("latex"))[["num_1"]],
     c("a \\$1,836.23 b", "a \\$2,763.39 b",
       "a \\$937.29 b", "a \\$643.00 b",
@@ -148,10 +148,10 @@ test_that("fmt_currency() works correctly", {
   # by 1/1000 and append a `K` character to the resultant values, use
   # all other defaults; extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
          columns = "num_1", currency = "USD", decimals = 4,
-         scale_by = 1/1000, pattern = "{x}K") %>%
+         scale_by = 1/1000, pattern = "{x}K") |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1.8362K", "\\$2.7634K", "\\$0.9373K",
       "\\$0.6430K", "\\$0.2122K", "\\$0.0000K",
@@ -161,9 +161,9 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column as USD, apply the `en_US` locale and use all
   # other defaults; extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "USD", locale = "en_US") %>%
+         columns = "num_1", currency = "USD", locale = "en_US") |>
        render_formats_test("latex"))[["num_1"]],
     c("\\$1,836.23", "\\$2,763.39", "\\$937.29",
       "\\$643.00", "\\$212.23", "\\$0.00",
@@ -173,10 +173,10 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column as DKK, apply the `da_DK` locale and use all
   # other defaults; extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
          columns = "num_1", currency = "DKK", locale = "da_DK",
-         placement = "right", incl_space = TRUE) %>%
+         placement = "right", incl_space = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
     c("1.836,23 kr.", "2.763,39 kr.",
       "937,29 kr.", "643,00 kr.", "212,23 kr.",
@@ -186,9 +186,9 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column as DKK, apply the `da_DK` locale and use all
   # other defaults; extract `output_df`, and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "DKK", locale = "da_DK") %>%
+         columns = "num_1", currency = "DKK", locale = "da_DK") |>
        render_formats_test("latex"))[["num_1"]],
     c("kr.1.836,23", "kr.2.763,39", "kr.937,29",
       "kr.643,00", "kr.212,23", "kr.0,00",
@@ -198,9 +198,9 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column as EUR, apply the `de_AT` locale and use all
   # other defaults; extract `output_df` and compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "EUR", locale = "de_AT") %>%
+         columns = "num_1", currency = "EUR", locale = "de_AT") |>
        render_formats_test("latex"))[["num_1"]],
     c("EUR1 836,23", "EUR2 763,39", "EUR937,29",
       "EUR643,00", "EUR212,23", "EUR0,00",
@@ -211,9 +211,9 @@ test_that("fmt_currency() works correctly", {
   # other defaults; use the default context, extract `output_df`, and
   # compare to expected values
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "EUR", locale = "de_AT") %>%
+         columns = "num_1", currency = "EUR", locale = "de_AT") |>
        render_formats_test("latex"))[["num_1"]],
     c("EUR1 836,23", "EUR2 763,39", "EUR937,29",
       "EUR643,00", "EUR212,23", "EUR0,00",
@@ -223,12 +223,14 @@ test_that("fmt_currency() works correctly", {
   # Format the `num_1` column to 2 decimal places, apply the `et_EE`
   # locale and use all other defaults; extract `output_df` and compare
   # to expected values
+  # Note: Estonian (et) has minimum_grouping_digits=2 (CLDR), so only numbers
+  # with 5+ digits (10000+) get separators
   expect_equal(
-    (tbl_latex %>%
+    (tbl_latex |>
        fmt_currency(
-         columns = "num_1", currency = "EUR", locale = "et_EE") %>%
+         columns = "num_1", currency = "EUR", locale = "et_EE") |>
        render_formats_test("latex"))[["num_1"]],
-    c("EUR1 836,23", "EUR2 763,39", "EUR937,29",
+    c("EUR1836,23", "EUR2763,39", "EUR937,29",
       "EUR643,00", "EUR212,23", "EUR0,00",
       "-EUR23,24")
   )
