@@ -1,4 +1,4 @@
-test_that("fmt_integer() works correctly in the LaTeX context", {
+test_that("fmt_integer() works correctly in LaTeX output tables", {
 
   # Create an input data frame four columns: two
   # character-based and two that are numeric
@@ -36,21 +36,21 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Expect an error when attempting to format a column
   # that does not exist
   expect_error(
-    tab %>%
+    tab |>
       fmt_integer(columns = num_3)
   )
 
   # Expect an error when using a locale that does not exist
   expect_error(
-    tab %>%
+    tab |>
       fmt_integer(columns = num_2, locale = "aa_bb")
   )
 
   # Format the `num_1` column, use all
   # other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1) %>%
+    (tab |>
+       fmt_integer(columns = num_1) |>
        render_formats_test(context = "latex"))[["num_1"]],
     c("1,836", "2,763", "937", "643", "212", "0", "-23")
   )
@@ -58,8 +58,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, don't use digit
   # grouping separators, use all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, use_seps = FALSE) %>%
+    (tab |>
+       fmt_integer(columns = num_1, use_seps = FALSE) |>
        render_formats_test("latex"))[["num_1"]],
     c("1836", "2763", "937", "643", "212", "0", "-23")
   )
@@ -67,8 +67,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, use a single space
   # character as digit grouping separators, use all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, sep_mark = " ") %>%
+    (tab |>
+       fmt_integer(columns = num_1, sep_mark = " ") |>
        render_formats_test("latex"))[["num_1"]],
     c("1 836", "2 763", "937", "643", "212", "0", "-23")
   )
@@ -76,8 +76,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, use a period for the
   # digit grouping separators
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, sep_mark = ".") %>%
+    (tab |>
+       fmt_integer(columns = num_1, sep_mark = ".") |>
        render_formats_test("latex"))[["num_1"]],
     c("1.836", "2.763", "937", "643", "212", "0", "-23")
   )
@@ -85,8 +85,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, scale all values by
   # 1/1000, use all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, scale_by = 1/1000) %>%
+    (tab |>
+       fmt_integer(columns = num_1, scale_by = 1/1000) |>
        render_formats_test("latex"))[["num_1"]],
     c("2", "3", "1", "1", "0", "0", "0")
   )
@@ -94,8 +94,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, prepend and append
   # all values by 2 different literals, use all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, pattern = "a {x} b") %>%
+    (tab |>
+       fmt_integer(columns = num_1, pattern = "a {x} b") |>
        render_formats_test("latex"))[["num_1"]],
     c("a 1,836 b", "a 2,763 b", "a 937 b", "a 643 b", "a 212 b",
       "a 0 b", "a -23 b")
@@ -105,16 +105,16 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # by 1/1000 and append a `K` character to the resultant values, use
   # all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, scale_by = 1/1000, pattern = "{x}K") %>%
+    (tab |>
+       fmt_integer(columns = num_1, scale_by = 1/1000, pattern = "{x}K") |>
        render_formats_test("latex"))[["num_1"]],
     c("2K", "3K", "1K", "1K", "0K", "0K", "0K")
   )
 
   # Format the `num_1` column, use accounting style
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, accounting = TRUE) %>%
+    (tab |>
+       fmt_integer(columns = num_1, accounting = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
     c("1,836", "2,763", "937", "643", "212", "0", "(23)")
   )
@@ -122,9 +122,9 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, use accounting style
   # and a pattern around the values
   expect_equal(
-    (tab %>%
+    (tab |>
        fmt_integer(
-         columns = num_1, accounting = TRUE, pattern = "a{x}b") %>%
+         columns = num_1, accounting = TRUE, pattern = "a{x}b") |>
        render_formats_test("latex"))[["num_1"]],
     c("a1,836b", "a2,763b", "a937b", "a643b", "a212b",
       "a0b", "a(23)b")
@@ -132,9 +132,9 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
 
   # Format the `num_1` column to 2 decimal places, force the sign
   expect_equal(
-    (tab %>%
+    (tab |>
        fmt_integer(
-         columns = num_1, force_sign = TRUE) %>%
+         columns = num_1, force_sign = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
     c("+1,836", "+2,763", "+937", "+643", "+212", "0", "-23")
   )
@@ -142,22 +142,22 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Expect that using `force_sign = TRUE` with `accounting = TRUE`
   # will render values in accounting format
   expect_equal(
-    (tab %>%
+    (tab |>
        fmt_integer(
-         columns = num_1, accounting = TRUE, force_sign = TRUE) %>%
+         columns = num_1, accounting = TRUE, force_sign = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
-    (tab %>%
+    (tab |>
        fmt_integer(
-         columns = num_1, accounting = TRUE) %>%
+         columns = num_1, accounting = TRUE) |>
        render_formats_test("latex"))[["num_1"]]
   )
 
   # Format the `num_1` column to 2 decimal places, force the sign and
   # define a pattern for decorating values
   expect_equal(
-    (tab %>%
+    (tab |>
        fmt_integer(
-         columns = num_1, pattern = "*{x}*", force_sign = TRUE) %>%
+         columns = num_1, pattern = "*{x}*", force_sign = TRUE) |>
        render_formats_test("latex"))[["num_1"]],
     c(
       "*+1,836*", "*+2,763*", "*+937*", "*+643*", "*+212*",
@@ -168,8 +168,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1`, apply the `en_US`
   # locale and use all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, locale = "en_US") %>%
+    (tab |>
+       fmt_integer(columns = num_1, locale = "en_US") |>
        render_formats_test("latex"))[["num_1"]],
     c("1,836", "2,763", "937", "643", "212", "0", "-23")
   )
@@ -177,8 +177,8 @@ test_that("fmt_integer() works correctly in the LaTeX context", {
   # Format the `num_1` column, apply the `da_DK`
   # locale and use all other defaults
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num_1, locale = "da_DK") %>%
+    (tab |>
+       fmt_integer(columns = num_1, locale = "da_DK") |>
        render_formats_test("latex"))[["num_1"]],
     c("1.836", "2.763", "937", "643", "212", "0", "-23")
   )
@@ -204,8 +204,8 @@ test_that("fmt_integer() can scale/suffix larger numbers", {
   # Format the `num` column, have the `suffixing` option
   # set to TRUE (default labels, all 4 ranges used)
   expect_equal(
-    (tab %>%
-       fmt_integer(columns = num, suffixing = TRUE) %>%
+    (tab |>
+       fmt_integer(columns = num, suffixing = TRUE) |>
        render_formats_test(context = "latex"))[["num"]],
     c(
       "-1,800T", "-17T", "-16B", "-150M", "-1M", "-13K",
@@ -217,10 +217,10 @@ test_that("fmt_integer() can scale/suffix larger numbers", {
   # Format the `num` column, have the `suffixing`
   # option set to use custom symbols across the 4 different ranges
   expect_equal(
-    (tab %>%
+    (tab |>
        fmt_integer(
          columns = num,
-         suffixing = c("k", "Mn", "Bn", "Tr")) %>%
+         suffixing = c("k", "Mn", "Bn", "Tr")) |>
        render_formats_test(context = "latex"))[["num"]],
     c(
       "-1,800Tr", "-17Tr", "-16Bn", "-150Mn", "-1Mn", "-13k",
@@ -232,10 +232,10 @@ test_that("fmt_integer() can scale/suffix larger numbers", {
   # Format the `num` column, have the `suffixing` option
   # set to use custom symbols for the middle two ranges (millions and billions)
   expect_equal(
-    (tab %>%
+    (tab |>
        fmt_integer(
          columns = num,
-         suffixing = c(NA, "Mio.", "Mia.", NA)) %>%
+         suffixing = c(NA, "Mio.", "Mia.", NA)) |>
        render_formats_test(context = "latex"))[["num"]],
     c(
       "-1,800,000Mia.", "-17,000Mia.", "-16Mia.", "-150Mio.",
